# UTF-8 encoded German translation file for use with Oddmuse
#
# Copyright (c) 2003  Karl Loncarek <karl@loncarek.de>
# Copyright (c) 2003, 2004, 2005, 2006  Alex Schröder <alex@emacswiki.org>
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
$ModulesDescription .= '<p>$Id: german-utf8.pl,v 1.15 2006/05/10 22:52:16 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Lesen nicht erlaubt: Benutzer, IP oder Netzwerk ist gesperrt.
Could not create %s
Konnte %s nicht erzeugen
Invalid UserName %s: not saved.
Ungültiger Benutzername %s: nicht gespeichert.
UserName must be 50 characters or less: not saved
Länge des Benutzernamens maximal 50 Zeichen: nicht gespeichert.
This page contains an uploaded file:
Diese Seite enthält eine hochgeladene Datei:
Recursive include of %s!
%s wird rekursiv eingelesen!
XML::RSS is not available on this system.
Das XML::RSS Modul ist auf diesem System nicht installiert.
diff
Unterschiede
history
alte Versionen
%s returned no data, or LWP::UserAgent is not available.
Entweder liefert %s liefert keine Daten, oder das LWP::UserAgent Modul ist auf diesem System nicht installiert.
RSS parsing failed for %s
Die RSS Daten von %s sind ungültig; sie können nicht verarbeitet werden
No items found in %s.
%s liefert keine Artikel
 . . . . 
 . . . . 
Click to edit this page
Hier klicken um die Seite zu bearbeiten
image
image
download
download
CGI Internal error: %s
Interner CGI Fehler: %s
Invalid action parameter %s
Ungültiger action Parameter: %s
Invalid URL.
Ungültige URL.
Page name is missing
Seitenname fehlt
Page name is too long: %s
Seitenname zu lang: %s
Invalid Page %s (must not end with .db)
Ungültige Seite %s (Darf nicht mit .db enden)
Invalid Page %s (must not end with .lck)
Ungültige Seite %s (Darf nicht mit .lck enden)
Invalid Page %s
Ungültige Seite %s
Preview:
Vorschau:
Preview only, not yet saved
Vorschau, noch nicht gespeichert
Please go on to %s.
Bitte machen Sie weiter bei %s.
Could not open %s log file
Kann Logdatei %s nicht öffnen
Error was
Fehler war
Note: This error is normal if no changes have been made.
HINWEIS: Dieser Fehler ist normal, wenn keine Änderungen durchgeführt wurden.
Could not open old %s log file
Konnte alte Logdatei %s nicht öffnen
No updates since %s
Keine Änderungen seit %s
Updates since %s
Änderungen seit %s
Updates in the last %s days
Änderungen der letzten %s Tage
Updates in the last %s day
Änderungen der letzten %s Tage
for %s only
nur für %s
List latest change per page only
Nur letzte Änderungen pro Seite
List all changes
Alle Änderungen
List only major changes
Nur grössere Änderungen
Include minor changes
Inklusive kleinere Änderungen
%s days
%s Tage
List later changes
Spätere Änderungen
Filters
Filter
Title:
Seitenname:
Title and Body:
Seitenname und Inhalt:
Username:
Benutzername:
Host:
Rechner:
Language:
Sprache:
Go!
Los!
(minor)
(Klein)
rollback
bis hier alles Rückgängig machen
new
Neue Seite
from %s
von %s
This page is too big to send over RSS.
Diese Seite ist zu gross für RSS.
History of %s
Andere Versionen von %s
Compare
Vergleichen
Revision %s
Version %s
by
von
Rolling back changes
Änderungen werden rückgängig gemacht
Missing target for rollback.
Das Stichdatum fehlt.
Target for rollback is too far back.
Das Stichdatum liegt zu weit zurück.
Rollback to %s
Rückgängig gemacht auf den Stand vom %s
%s rolled back
Änderungen für %s rückgängig gemacht
Index of all pages
Index aller Seiten
Wiki Version
Wiki Version
Unlock Wiki
Aufheben der Sperren
Password
Passwort
Run maintenance
Wartungsarbeiten durchführen
Unlock site
Wiki entsperren
Lock site
Wiki sperren
Install CSS
CSS installieren
Unlock %s
%s entsperren
Lock %s
%s sperren
Administration
Administration
Actions:
Aktionen:
Important pages:
Wichtige Seiten:
To mark a page for deletion, put <strong>%s</strong> on the first line.
Um eine Seite zu löschen, setzt man <strong>%s</strong> auf die erste Zeile.
[Home]
[Erste Seite]
redirected from %s
Umgeleitet von %s
Click to search for references to this page
Klicken um nach Verweisen auf diese Seite zu suchen
Cookie: 
Cookie: 
Warning
Warnung
Database is stored in temporary directory %s
Datenbank wird im temporären Verzeichnis %s gespeichert
%s seconds
%s Sekunden
The same page on other sites:
Dieselbe Seite auf anderen Sites:
EditNearLinks
Diese Seiten lokal erstellen
Last edited
Zuletzt geändert
Edited
Geändert
by %s
von %s
(diff)
(Unterschiede)
Edit revision %s of this page
Version %s dieser Seite bearbeiten
Edit this page
Diese Seite bearbeiten
e
b
This page is read-only
Diese Seite ist schreibgeschützt
View other revisions
Andere Versionen dieser Seite
View current revision
Zurück zur aktuellen Version
View all changes
Liste aller Änderungen, auch ohne vorhandener Version
Homepage URL:
Homepage URL:
s
s
Save
Speichern
p
p
Preview
Vorschau
Search:
Suchen:
f
f
Replace:
Ersetzen mit:
Validate HTML
HTML überprüfen
Validate CSS
CSS überprüfen
Difference (from revision %1 to %2)
Unterschiede (zwischen Version %1 und %2)
revision %s
Version %s
current revision
Aktuelle Version
Difference (from prior %s revision)
(%s Änderungen)
major
größere
minor
kleinere
No diff available.
Keine Unterschiede vorhanden.
The two revisions are the same.
Es gibt keinen Unterschied zwischen den beiden Versionen.
Old revision:
Alte Version:
Changed:
Geändert:
Removed:
Gelöscht:
Added:
Eingefügt:
to
stattdessen:
Revision %s not available
Version %s nicht verfügbar
showing current revision instead
Stattdessen Anzeige der aktuellen Version
Showing revision %s
Anzeige der alten Version %s
Cannot save a nameless page.
Eine Seite ohne Namen kann nicht gespeichert werden.
Cannot save a page without revision.
Ohne Version kann die Seite nicht gespeichert werden.
Cannot open %s
%s kann nicht geöffnet werden
Cannot write %s
%s kann nicht geschrieben werden
Cannot create %s
%s kann nicht erstellt werden
Could not get %s lock
Die %s Sperre konnte nicht gesetzt werden.
The lock was created %s.
Die Sperre wurde %s gesetzt.
This operation may take several seconds...
Das könnte einige Sekunden dauern...
Forced unlock of %s lock.
Erzwungene Aufhebung der Sperre von %s.
No unlock required.
Aufhebung der Sperre nicht notwendig.
%s hours ago
vor %s Stunden
1 hour ago
vor einer Stunde
%s minutes ago
vor %s Minuten
1 minute ago
vor einer Minute
%s seconds ago
vor %s Sekunden
1 second ago
vor einer Sekunde
just now
gerade eben
Edit Denied
Bearbeiten verboten
Editing not allowed: user, ip, or network is blocked.
Bearbeitung nicht erlaubt: Benutzer, IP oder Netzwerk ist gesperrt.
Contact the wiki administrator for more information.
Für weitere Informationen setzen Sie sich mit dem Wiki Administrator in Verbindung.
The rule %s matched for you.
Die Regel %s hat angesprochen.
See %s for more information.
Siehe %s für weitere Informationen.
Editing not allowed: %s is read-only.
Bearbeitung nicht erlaubt: %s ist schreibgeschützt.
Only administrators can upload files.
Nur Administratoren dürfen Dateien hochladen.
Editing revision %s of
Bearbeiten der Version %s von
Editing %s
Bearbeiten von %s
Editing old revision %s.
Hiermit wird die alte Version %s bearbeitet.
Saving this page will replace the latest revision with this text.
Wird diese Änderung gespeichert, wird dies die aktuelle Version ersetzen. Damit werden die später gemachten Änderungen verloren gehen.
Summary:
Zusammenfassung:
This change is a minor edit.
Dies ist eine kleinere Änderung.
Replace this file with text.
Diese Datei durch Text ersetzen.
Replace this text with a file.
Datei hochladen und den Text durch diese Datei ersetzen.
File to upload: 
Hochzuladende Datei: 
Files of type %s are not allowed.
Der Dateityp %s ist nicht erlaubt.
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Ihr Passwort wird in einem Cookie gespeichert, falls Sie Cookies eingeschaltet haben. Cookies können verloren gehen, wenn Sie die Verbindung von einer anderen Maschine, von einem anderen Account oder mit anderer Software herstellen.
You are currently an administrator on this site.
Sie sind momentan ein Administrator auf dieser Webseite.
You are currently an editor on this site.
Sie sind momentan ein Redaktor auf dieser Webseite.
You are a normal user on this site.
Sie sind ein normaler Benutzer auf dieser Webseite.
Your password does not match any of the  administrator or editor passwords.
Ihr Passwort stimmt nicht mit einem Administrator- oder Redaktor-Passwort überein.
Password:
Passwort:
This site does not use admin or editor passwords.
Diese Webseite verwendet keine Administrator- oder Redaktor-Passwörter.
This operation is restricted to site editors only...
Diese Aktion darf nur von Redaktoren durchgeführt werden...
This operation is restricted to administrators only...
Diese Aktion darf nur von Administratoren durchgeführt werden...
Rule "%1" matched "%2" on this page.
Auf dieser Seite verstösst "%2" gegen die Regel "%1".
Without normal pages
Ohne normale Seiten
Include normal pages
Mit normalen Seiten
Without permanent anchors
Ohne permanente Anker
Include permanent anchors
Mit permanenten Ankern
Without near pages
Ohne Seiten aus der Umgebung
Include near pages
Mit Seiten aus der Umgebung
(for %s)
(für %s)
Filter:
Filter:
%s pages found.
%s Seiten gefunden.
Replaced: %s
Ersetzt: %s
Search for: %s
Suche nach: %s
View changes for these pages
Änderungen für diese Seiten
Search sites on the %s as well
Sites auf der %s auch durchsuchen
and
und
or
oder
Fetching results from %s:
Resultate von %s:
Near pages:
Nahe Seiten:
last updated
Zuletzt geändert
Complete Content
Vollständiger Inhalt
The main page is %s.
Die Hauptseite ist %s.
Comments on this page
Kommentare zu dieser Seite
Editing not allowed for %s.
Das bearbeiten von %s ist nicht erlaubt.
SampleUndefinedPage
BeispielEinerUndefiniertenSeite
%s cannot be defined.
%s kann nicht definiert werden.
Sample_Undefined_Page
Beispiel_Einer_Undefinierten_Seite
[[%s]] cannot be defined.
[[%s]] kann nicht definiert werden.
Only an administrator can create %s.
Nur ein Administrator can %s erstellen.
Transfer Error: %s
Transferfehler: %s
Browser reports no file info.
Der Browser hat keine Dateiinformationen geliefert.
Browser reports no file type.
Der Browser hat keinen Dateityp geliefert.
The page contains banned text.
Diese Seite enthält verbotenen Text.
No changes to be saved.
Es wurde nichts geändert.
This page was changed by somebody else %s.
Diese Seite wurde von einer anderen Person %s verändert.
The changes conflict.  Please check the page again.
Die Änderungen beeinträchtigen sich gegenseitig.  Bitte überprüfen Sie die Seite nochmals.
Please check whether you overwrote those changes.
Bitte überprüfen Sie, ob diese Änderungen überschrieben worden sind.
Anonymous
Unbekannt
Cannot delete the index file %s.
Die Index Datei %s kann nicht gelöscht werden.
Please check the directory permissions.
Bitte prüfen Sie die Berechtigungen des Verzeichnisses.
Your changes were not saved.
Ihre Änderungen wurden nicht gespeichert.
Could not get a lock to merge!
Sperre zum automatischen Abgleichen zweier Versionen konnte nicht reserviert werden!
you
Sie
ancestor
Vorgänger
other
Andere Person
Run Maintenance
Wartungsarbeiten
Maintenance not done.
Wartungsarbeiten nicht erfolgt.
(Maintenance can only be done once every 12 hours.)
(Wartungsarbeiten können frühestens alle 12 Stunden durchgeführt werden.)
Remove the "maintain" file or wait.
Löschen Sie die Datei "maintain" oder warten Sie.
Main lock obtained.
Hauptsperre aktiviert.
Expiring keep files and deleting pages marked for deletion
Alte Versionen werden aus dem Archiv entfernt und Seiten, die als gelöscht markiert wurden, werden gelöscht
not deleted: 
konnte nicht gelöscht werden: 
deleted
Datei gelöscht
Moving part of the %s log file.
Verschiebe einen Teil der Logdatei %s.
Moving %s log entries.
Verschiebe %s Log-Einträge.
Getting page index file for %s.
Hole den Seitenindex für %s.
Main lock released.
Hauptsperre aufgehoben.
Set or Remove global edit lock
Erzeugen oder Aufheben der globalen Bearbeitungssperre
Edit lock created.
Bearbeitungssperre erzeugt.
Edit lock removed.
Bearbeitungssperre aufgehoben.
Set or Remove page edit lock
Erzeugen oder aufheben der Seiten-Bearbeitungssperre
Lock for %s created.
Sperre von %s erzeugt.
Lock for %s removed.
Sperre von %s aufheben.
Displaying Wiki Version
Anzeite der Wikiversion
Show dependencies
Abhängigkeiten zeigen
Inter links:
Inter Links:
Near links:
Nahe Links:
Show parsed link data
Eingelesene Link Daten anzeigen
Too many connections by %s
Zu viele Verbindungen durch %s
Please do not fetch more than %1 pages in %2 seconds.
Bitte rufen sie nicht mehr als %1 Seiten in %2 Sekunden auf.
Check whether the web server can create the directory %s and whether it can create files in it.
Vielleicht kann der web server das Verzeichnis %s nicht anlegen, oder es wurde schon angelegt, aber der web server kann darin keine neuen Dateien anlegen.
anchor first defined here: %s
Der Anker wurde hier zuerst definiert: %s
Click to search for references to this permanent anchor
Klicken um nach Verweisen auf diesen permanenten Anker zu suchen
the page %s also exists
die Seite %s existiert ebenfalls
Copy one of the following stylesheets to %s:
Eines der folgenden Style Sheets kann auf die %s Seite kopiert werden:
Deleting %s
%s löschen
Deleted %s
%s wurde gelöscht
Renaming %1 to %2.
Die %1 Seite wird zu %2 umbenannt
The page %s does not exist
Die %s Seite gibt es nicht
The page %s already exists
Die %s Seite gibt es schon
Cannot rename %1 to %2
%1 kannn nicht zu %2 umbenannt werden
Renamed to %s
Wurde auf %s umbenannt
Renamed from %s
Ehemals %s
Renamed %1 to %2.
Die %1 Seite wurde zu %2 umbenannt
Immediately delete %s
%s sofort löschen
Rename %s to:
%s umbenennen zu:
Learn more...
Mehr dazu...
Cannot highlight the language %s.
Die Sprache %s kann von diesem Modul nicht eingefärbt werden.
Recent Visitors
Kürzliche Besucher
some action
Spezialaktion
was here
war hier
and read
und las
Illegal year value: Use 0001-9999
Nur Jahreszahlen im Bereich 0001-9999 sind hier erlaubt
The match parameter is missing.
Der 'match' Parameter fehlt noch.
Page Collection for %s
Seitensammlung für %s
Previous
Vorheriger
Next
Nächster
Calendar %s
Kalender %s
Su
So
Mo
Mo
Tu
Di
We
Mi
Th
Do
Fr
Fr
Sa
Sa
January
Januar
February
Februar
March
März
April
April
May
Mai
June
Juni
July
Juli
August
August
September
September
October
Oktober
November
November
December
Dezember
Clustermap
Clustermap
Pages without a Cluster
Seiten ohne Cluster
Comments on 
Kommentare zu 
Comment on 
Kommentar zu 
Compilation for %s
Zusammenstellung für %s
Compilation tag is missing a regular expression.
Der tag für die Zusammenstellung benötigt noch ein Suchmuster.
Despamming pages
Spam entfernen
Cannot find revision %s.
Die Version %s ist verschwunden.
Revert to revision %1: %2
Auf Version %1 zurückgesetzt: %2
Marked as %s.
Mit %s markiert. 
Cannot find unspammed revision.
Es gibt keine Version ohne Spam.
Add Comment
Kommentar hinzufügen
ordinary changes
normale Änderungen
Footnotes:
Fussnoten:
Could not find %1.html template in %2
Im Verzeichnis %2 gibt es kein %1.html Template
Only Editors are allowed to see hidden pages.
Nur Redaktoren dürfen versteckte Seiten sehen.
Only Admins are allowed to see hidden pages.
Nur Administratoren dürfen versteckte Seiten sehen.
image: %s
Bild: %s
Index
Index
Languages:
Sprachen:
Show!
Zeigen!
Define
Definieren
Full Link List
Liste aller Verweise
Template without parameters
Vorlage ohne Parameter
The template %s is either empty or does not exist.
Die %s Vorlage ist entweder leer oder existiert gar nicht.
 -- defined on %s
 -- definiert auf der Seite %s
Local names defined on %1: %2
Der lokale Namen %2 wurde auf der Seite %1 definiert
Register for %s
Anmeldung für %s
Please choose a username of the form "FirstLast" using your real name.
Bitte verwenden sie ihren Vorname und Nachname ohne Leerzeichen ("VornameNachname") als ihren Benutzernamen.
The passwords do not match.
Das Passwort stimmt nicht mit der Kopie überein.
The password must be at least %s characters.
Das Passwort muss mindestens %s Zeichen lang sein.
That email address is invalid.
Diese Email Adresse ist ungültig.
The username %s has already been registered.
Der Benutzername %s existiert bereits.
Your registration for %s has been submitted.
Ihre Anmeldung für den Benutzername %s wurde weitergeleitet.
Please allow time for the webmaster to approve your request.
Bitte geben Sie dem Webmaster etwas Zeit, um ihr Gesuch zu bewilligen.
An email has been sent to "%s" with further instructions.
Eine Email mit weiteren Instruktionen wurde an %s verschickt.
There was an error saving your registration.
Es gab einen Fehler beim Speichern ihrer Registrierung.
An account was created for %s.
Der Benutzername %s wurde angelegt.
Login to %s
Anmeldung für %s
Username and/or password are incorrect.
Benutzername und/oder Passwort sind falsch.
Logged in as %s.
%s wurde erfolgreich angemeldet.
Logout of %s
%s wurde erfolgreich abgemeldet.
Logout of %s?
Von %s abmelden?
Logged out of %s
%s wurde erfolgreich abgemeldet.
You are now logged out.
Sie sind nun abgemeldet.
Register a new account
Neue Anmeldung
Login
Anmeldung
Logout
Abmeldung
Who am I?
Wer bin ich?
Forgot your password?
Passwort vergessen?
Change your password
Passwort ändern
Approve pending registrations
Die verbleibenden Gesuche bewilligen
Confirm Registration for %s
Die Registrierung für %s bestätigen
%s, your registration has been approved. You can now use your password to login and edit this wiki.
Ihr Gesuch wurde angenommen. Sie können nun mit ihrem Passwort einsteigen und das Wiki verändern.
Confirmation failed.  Please email %s for help.
Die Bestätigung ist fehlgeschlagen. Senden sie eine Mail an %s um Hilfe zu erhalten.
Who Am I?
Wer bin ich?
You are logged in as %s.
Sie sind als %s angemeldet.
You are not logged in.
Sie sind nicht angemeldet.
Reset Password
Passwort zurücksetzen
The password for %s was reset.  It has been emailed to the address on file.
Das Passwort für %s wurde zurückgesetzt. Eine entsprechende Email wurde an die dazugehörige Adresse geschickt.
There was an error resetting the password for %s.
Das Passwort konnte für %s wegen einem Fehler nicht gesetzt werden.
The username "%s" does not exist.
Der Benutzer "%s" existiert nicht.
Reset Password for %s
Passwort für %s zurücksetzen
Reset Password?
Passwort zurücksetzen?
Change Password for %s
Das Passwort für %s zurücksetzen
Change Password?
Passwort ändern
Your current password is incorrect.
Das aktuelle Passwort ist nicht korrekt.
Your password has been changed.
Das Passwort wurde geändert.
Approve Pending Registrations for %s
Offene Gesuche für %s bestätigen
%s has been approved.
%s wurde bestätigt.
There was an error approving %s.
Bei der Bestätigung von %s ist ein Fehler aufgetreten.
<ul>
<ul>
<li>%1 - %2</li>
<li>%1 - %2</li>
</ul>
</ul>
There are no pending registrations.
Es gibt keine offenen Gesuche.
%s is not a legal name for a namespace
%s ist ein ungültiger Name für einen Namensraum
Clearing Cache
Cache wird geleert
Done.
Fertig.
Generating Link Database
Verweis Datenbank wird angelegt
The 404 handler extension requires the link data extension (links.pl).
Die 404 handler Erweiterung benötigt die Link Data Erweiterung (links.pl).
LocalMap

No page id for action localmap
Es gibt keine Spezialseite für den localmap Befehle
Requested page %s does not exist
Die gewünschte Seite %s existiert nicht
Local Map for %s

view

Self-ban by %s
%s hat sich selber verbannt.
You have banned your own IP.
Sie haben ihre eigene IP Nummer verbannt.
Orphan List
Liste der Waisen
Trail: 
Weg: 
None
Keiner
Type
Typ
Permalink to "%s"
Permalink für "%s"
There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.
Es gab einen Fehler beim Generieren der PDF Datei für %s. Bitte teilen Sie dies dem Webmeister mit.  Ein erneuter Versuch, diese Datei zu erhalten, wird nicht funktionieren.
Someone else is generating a pdf for %s.  Please wait a minute and then try again.
Gerade eben erstellt jemand eine PDF Datei für %s.  Bitte warten Sie eine Minute und versuchen es dann nochmal.
Download this page as PDF
Diese Seite als PDF
Portrait
Portrait
You did not answer correctly.
Die Antwort ist falsch.
All Referrers
Alle Links auf diesen Wiki
Referrers
Links auf diese Seite
Tag
Tag
Rebuild index for searching
Der Index für die Suche wird neu erstellt
Tag Cloud
Tag Wolke
Search::FreeText is not available on this system.
Search::FreeText fehlt auf diesem System.
Rebuilding index not done.
Der Index für die Suche wurde noch nicht neu erstellt.
(Rebuilding the index can only be done once every 12 hours.)
(Der Index für die Suche kann nur einmal alle zwölf Stunden neu erstellt werden.)
 ... 
 … 
Search term missing.
Der Suchbegriff fehlt.
Result pages: 
Resultate: 
(%s results)
(%s Resultate)
Slideshow:%s
Diashow:%s
Static Copy
Statische Kopie
Back to %s
Zurück zu %s
Copy to %1 succeeded: %2.
Die %1 Kopie hat funktioniert: %2.
Copy to %1 failed: %2.
Die %1 Kopie ist fehlgeschlagen: %2.
Alternatively, use one of the following templates:
Anderenfalls stehen auch folgende Vorlagen zur Verfügung:
Thread: %s
Thread: %s
ID parameter is missing.
ID Parameter fehlt noch.
Thread %s does not exist.
Den %s Thread gibt es nicht.
Page %s does not contain a thread.
Die %s Seite enthält keinen Thread.
Add
Hinzufügen
URL parameter is missing.
URL Parameter fehlt noch.
Add to %s thread
Zum %s Thread hinzufügen
Below:
Darunter:
URL:
URL:
Name:
Name:
Failed to remove %s
%s konnte nicht entfernt werden.
Contents
Inhaltsverzeichnis
This page is a translation of %s. 
Diese Seite ist eine Übersetzung von %s. 
The translation is up to date.
Die Übersetztung ist aktuell.
The translation is outdated.
Die Übersetzung ist veraltet.
The page does not exist.
Die Seite existiert nicht.
http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s
http://www.amazon.de/exec/obidos/ISBN=%s
alternate
Alternativ
http://www.pricescan.com/books/BookDetail.asp?isbn=%s
http://de.bookbutler.info/vergleich/%s
search
Suchen
Upload of %s file
Hochladen der %s Datei
Blog
Blog
Matching pages:
Passende Seiten:
New
Neu
Edit %s.
%s bearbeiten.
END_OF_TRANSLATION
